@@ -6,6 +6,7 @@ import typer
 from rich.console import Console
 from rich.table import Table
 
+from seshat.general.command import SubmitCommand
 from seshat.general.command import (
     SubmitCommand,
     JobMetadata,
@@ -13,6 +14,7 @@ from seshat.general.command import (
     ExecutionMode,
 )
 from seshat.general.command.code_inspect import CodeInspectCommand
+from seshat.general.command.generate_story import GenerateStoryCommand
 from seshat.general.command.job_status import JobStatusCommand
 from seshat.general.command.setup_project import RECOMMENDATION, SetUpProjectCommand
 from seshat.general.exceptions import NoConfigSetError, RestClientException
@@ -319,8 +321,11 @@ def configure_job(
         "", prompt=True, help="Start time (YYYY-MM-DDTHH:MM)"
     ),
     until: str = typer.Option("", prompt=True, help="Until time (YYYY-MM-DDTHH:MM)"),
+    interval: int = typer.Option("", prompt=True, help="Interval for scheduling jobs"),
     cron_expression: str = typer.Option(
-        "", prompt=True, help="Cron expression for schedule (if applicable)"
+        "",
+        prompt=True,
+        help="Cron expression for schedule (keep empty if interval is provided)",
     ),
     run_overlap: str = typer.Option(
         "true", prompt=True, help="Allow overlapping runs (true/false)"
@@ -364,6 +369,7 @@ def configure_job(
                 "start_time": start_time,
                 "until": until,
                 "cron_expression": cron_expression,
+                "interval": interval,
                 "run_overlap": run_overlap,
             }
         },
@@ -426,6 +432,27 @@ def job_status(
         raise typer.Exit(1)
 
 
+@app.command(name="generate-story")
+def generate_story(
+    file_path: Path = typer.Option(
+        None,
+        "--file",
+        "-f",
+        help="Path to output story.json file (default: ./story.json)",
+    )
+):
+    result = GenerateStoryCommand().generate()
+    if file_path is None:
+        file_path = Path("story.json")
+    try:
+        with open(file_path, "w") as f:
+            f.write(result)
+        typer.echo(f"Story written to {file_path}")
+    except Exception as e:
+        typer.echo(f"Failed to write story to {file_path}: {e}", err=True)
+        raise typer.Exit(1)
+
+
 @app.callback()
 def main(verbose: bool = False):
     state["verbose"] = verbose
